#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Tue Nov  6 14:00:56 2018

@author: nicolai & audiffren
"""

import numpy as np
import argparse
from swarii import SWARII, WBB_parser
from gmm_classification import GMM_Score_predictor
import warnings
from plots import create_animated_stato, plot_score


warnings.filterwarnings("ignore")


if __name__ == "__main__":

    # Argument Parsing

    args = argparse.ArgumentParser()
    args.add_argument('input', metavar='input', type=str, nargs='+',
                       help='path of the input')
    args.add_argument('block_size', metavar='block_size', type=int, nargs='+',
                       help='time unit')
    args.add_argument('eyes', metavar='eyes', type=str, nargs='+',
                       help='OE or CE')


    parsed_args = args.parse_args()
    file_address = parsed_args.input[0]
    block_size = parsed_args.block_size[0]
    eyes_type = parsed_args.eyes[0]

    # Reading input
    data = WBB_parser.parse(file_address)

    # Resampling
    data = np.array(SWARII.resample(data))


    # Scoring
    mygmm = GMM_Score_predictor(block_size=block_size,eye_type=eyes_type)
    scores = np.array(mygmm.predict(data))

    average_score = np.mean(scores)

    #probabilities are multiplied by 100 just for the sake of readability by the user
    average_score = int(100*(average_score))

    print(average_score)

    plot_score(average_score)
    create_animated_stato(data,scores,block_size*25,12)
